#[repr(u8)]pub enum DftData {
Show 16 variants
ZZ232 = 0,
ZZ233 = 1,
ZZ234 = 2,
ZZ235 = 3,
ZZ236 = 4,
ZZ237 = 5,
ZZ238 = 6,
ZZ239 = 7,
ZZ240 = 8,
ZZ241 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
ZZ232 = 0
CKBD pattern. For READ operations only, compare DOUT with checkerboard data pattern for each read cycle.
ZZ233 = 1
ICKBD pattern. For READ operations only, compare DOUT with inverse checkerboard data pattern for each read cycle.
ZZ234 = 2
Diagonal pattern. Used for READ operations only, compare DOUT to diagonal pattern.
ZZ235 = 3
Fixed data pattern. For READ operations, comparison to DOUT for selected groups; refer to R_ADR_CTRL[GRPSEL] for modules with multiple groups.
ZZ236 = 4
Random data pattern which will be generated based on the initial seed set in R_DATA; for READ operations, used for DOUT comparison of selected groups. For PROG operations, used to control DIN of selected groups.
ZZ237 = 5
DOUT based pattern. For READ operations only, DOUT of selected group will be latched in R_DATA. If more than one group is selected in R_ADR_CTRL[GRPSEL], the group with the lower index will be latched.
ZZ238 = 6
R_DATA based pattern. For READ operations, expected DOUT value of selected groups equals to R_DATA when XADR[0]==YADR[0] or ~R_DATA when XADR[0]!=YADR[0]. For PROG operations, DIN of selected groups equals R_DATA when XADR[0]==YADR[0] or ~R_DATA when XADR[0]!=YADR[0].
ZZ239 = 7
SCAN-IO pattern. For READ operations, control expected DOUT value of selected groups to SCAN-IO data pattern. For PROG operations, control DIN of selected groups to SCAN-IO data pattern.
ZZ240 = 8
REPAIR set. For PROG operation to IFR1(7,1) and IFR1(7,2), R_REPAIR0_0 and R_REPAIR0_1 or R_REPAIR1_0 and R_REPAIR1_1 will control DIN. For READ operation on IFR1(7,1) and IFR1(7,2), DOUT will be compared against R_REPAIR0_0 and R_REPAIR0_1 or R_REPAIR1_0 andR_REPAIR1_1. When this option is selected, only one flash block can be selected.
ZZ241 = 9
REPAIR load. For READ operation only, DOUT from IFR1(7,1) and IFR1(7,2) is loaded to R_REPAIR0 and R_REPAIR1.