#[repr(u8)]pub enum DftXadr {
Show 16 variants
Zz252 = 0,
Zz253 = 1,
Zz254 = 2,
Zz255 = 3,
Zz256 = 4,
Zz257 = 5,
Zz258 = 6,
Zz259 = 7,
Zz260 = 8,
Zz261 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
Zz252 = 0
XADR fixed, no change at all.
Zz253 = 1
XADR increased by 1 after row. For READ operation, XADR increases by 1 after reading the last word of row. For PROG operation, XADR increases by 1 after NVSTR falls.
Zz254 = 2
XADR increased for diagonal. For PROG-DIAGONAL operation, XADR is increased to create diagonal pattern.
Zz255 = 3
XADR increased by sector. During ERASE operation, XADR increased by number of rows in a sector when NVSTR falls.
Zz256 = 4
XADR inversed. XADR is inversed after reading one word or after programming one row when NVSTR falls.
Zz257 = 5
XADR increased by 2 after row. For READ operation, XADR is increased by 2 after reading the last word of a row. For PROG operation, XADR is increased by 2 when NVSTR falls.
Zz258 = 6
XADR[0] inversed. XADR[0] is inversed after reading one word or after programming one row when NVSTR falls.
Zz259 = 7
XADR increased by 1. For READ operations only, XADR increased by 1 after each read cycle.
Zz260 = 8
XADR decreased by 1 after row. For READ operations only, XADR is decreased by 1 after YADR decreases to 0.
Zz261 = 9
XADR decreased by 1. For READ operations only, XADR is decreased by 1 after each read cycle.