#[repr(u8)]pub enum DftYadr {
Show 16 variants
ZZ242 = 0,
ZZ243 = 1,
ZZ244 = 2,
ZZ245 = 3,
ZZ246 = 4,
ZZ247 = 5,
ZZ248 = 6,
ZZ249 = 7,
ZZ250 = 8,
ZZ251 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
ZZ242 = 0
YADR fixed, no change at all
ZZ243 = 1
YADR for ICKBD. For PROG and READ operations, YADR changed to generate inverse checkerboard pattern.
ZZ244 = 2
YADR for CKBD. For PROG and READ operations, YADR changed to generate checkerboard pattern.
ZZ245 = 3
YADR increased by 1. For READ operations, YADR increased by 1 after each read cycle. For PROG operations, YADR increased by 1 after YE falls.
ZZ246 = 4
YADR increased for diagonal. For PROG-DIAGONAL operation, YADR is increased to create diagonal pattern.
ZZ247 = 5
YADR inversed. YADR is inversed after reading one word or after programming one word when YE falls.
ZZ248 = 6
YADR[0] inversed. YADR[0] is inversed after reading one word or after programming one word when YE falls.
ZZ249 = 7
YADR increased by 1 after last row. For READ operations only, YADR is increased by 1 after XADR reaches last row.
ZZ250 = 8
YADR decreased by 1. For READ operations only, YADR is decreased by 1 after each read cycle.
ZZ251 = 9
YADR decreased by 1 after first row. For READ operations only, YADR is decreased by 1 after XADR decreases to 0.