#[repr(u8)]pub enum ProgAttr {
ZZ262 = 0,
ZZ263 = 1,
ZZ264 = 2,
ZZ265 = 3,
ZZ266 = 4,
ZZ267 = 5,
ZZ268 = 6,
ZZ269 = 7,
}Variants
ZZ262 = 0
One YE pulse will program one data slice group
ZZ263 = 1
One YE pulse will program two data slice groups
ZZ264 = 2
One YE pulse will program three data slice groups (reserved)
ZZ265 = 3
One YE pulse will program four data slice groups
ZZ266 = 4
One YE pulse will program five data slice groups (reserved)
ZZ267 = 5
One YE pulse will program six data slice groups (reserved)
ZZ268 = 6
One YE pulse will program seven data slice groups (reserved)
ZZ269 = 7
One YE pulse will program eight data slice groups (reserved)
Implementations